summaryrefslogtreecommitdiff
path: root/sw/source/core/txtnode
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/txtnode')
-rw-r--r--sw/source/core/txtnode/SwGrammarContact.cxx8
-rw-r--r--sw/source/core/txtnode/atrfld.cxx2
-rw-r--r--sw/source/core/txtnode/atrflyin.cxx70
-rw-r--r--sw/source/core/txtnode/atrftn.cxx44
-rw-r--r--sw/source/core/txtnode/fntcache.cxx76
-rw-r--r--sw/source/core/txtnode/fntcap.cxx50
-rw-r--r--sw/source/core/txtnode/ndtxt.cxx96
-rw-r--r--sw/source/core/txtnode/swfont.cxx28
-rw-r--r--sw/source/core/txtnode/thints.cxx4
-rw-r--r--sw/source/core/txtnode/txtedt.cxx128
10 files changed, 253 insertions, 253 deletions
diff --git a/sw/source/core/txtnode/SwGrammarContact.cxx b/sw/source/core/txtnode/SwGrammarContact.cxx
index 86291396e92a..0f900d44c83e 100644
--- a/sw/source/core/txtnode/SwGrammarContact.cxx
+++ b/sw/source/core/txtnode/SwGrammarContact.cxx
@@ -74,7 +74,7 @@ IMPL_LINK_TYPED( SwGrammarContact, TimerRepaint, Timer *, pTimer, void )
{ //Replace the old wrong list by the proxy list and repaint all frames
getMyTextNode()->SetGrammarCheck( mpProxyList );
mpProxyList = nullptr;
- SwTextFrm::repaintTextFrames( *getMyTextNode() );
+ SwTextFrame::repaintTextFrames( *getMyTextNode() );
}
}
}
@@ -91,7 +91,7 @@ void SwGrammarContact::updateCursorPosition( const SwPosition& rNewPos )
if( mpProxyList )
{ // replace old list by the proxy list and repaint
getMyTextNode()->SetGrammarCheck( mpProxyList );
- SwTextFrm::repaintTextFrames( *getMyTextNode() );
+ SwTextFrame::repaintTextFrames( *getMyTextNode() );
}
GetRegisteredInNonConst()->Remove( this ); // good bye old paragraph
mpProxyList = nullptr;
@@ -160,7 +160,7 @@ void SwGrammarContact::Modify( const SfxPoolItem* pOld, const SfxPoolItem * )
void SwGrammarContact::finishGrammarCheck( SwTextNode& rTextNode )
{
if( &rTextNode != GetRegisteredIn() ) // not my paragraph
- SwTextFrm::repaintTextFrames( rTextNode ); // can be repainted directly
+ SwTextFrame::repaintTextFrames( rTextNode ); // can be repainted directly
else
{
if( mpProxyList )
@@ -171,7 +171,7 @@ void SwGrammarContact::finishGrammarCheck( SwTextNode& rTextNode )
else if( getMyTextNode()->GetGrammarCheck() )
{ // all grammar problems seems to be gone, no delay needed
getMyTextNode()->SetGrammarCheck( nullptr );
- SwTextFrm::repaintTextFrames( *getMyTextNode() );
+ SwTextFrame::repaintTextFrames( *getMyTextNode() );
}
}
}
diff --git a/sw/source/core/txtnode/atrfld.cxx b/sw/source/core/txtnode/atrfld.cxx
index a201bf33ba60..a86a5a2cc98d 100644
--- a/sw/source/core/txtnode/atrfld.cxx
+++ b/sw/source/core/txtnode/atrfld.cxx
@@ -266,7 +266,7 @@ void SwFormatField::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
}
break;
case RES_DOCPOS_UPDATE:
- // Je nach DocPos aktualisieren (SwTextFrm::Modify())
+ // Je nach DocPos aktualisieren (SwTextFrame::Modify())
pTextNd->ModifyNotification( pNew, this );
return;
diff --git a/sw/source/core/txtnode/fntcache.cxx b/sw/source/core/txtnode/fntcache.cxx
index d1d94e8f3d79..f8189328cff6 100644
--- a/sw/source/core/txtnode/fntcache.cxx
+++ b/sw/source/core/txtnode/fntcache.cxx
@@ -254,14 +254,14 @@ static void lcl_calcLinePos( const CalcLinePosData &rData,
if ( rData.bSwitchL2R )
{
- rData.rInf.GetFrm()->SwitchLTRtoRTL( rStart );
- rData.rInf.GetFrm()->SwitchLTRtoRTL( rEnd );
+ rData.rInf.GetFrame()->SwitchLTRtoRTL( rStart );
+ rData.rInf.GetFrame()->SwitchLTRtoRTL( rEnd );
}
if ( rData.bSwitchH2V )
{
- rData.rInf.GetFrm()->SwitchHorizontalToVertical( rStart );
- rData.rInf.GetFrm()->SwitchHorizontalToVertical( rEnd );
+ rData.rInf.GetFrame()->SwitchHorizontalToVertical( rStart );
+ rData.rInf.GetFrame()->SwitchHorizontalToVertical( rEnd );
}
}
@@ -872,9 +872,9 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
// HACK: UNDERLINE_WAVE must not be abused any more, hence the grey wave
// line of the ExtendedAttributeSets will appear in the font color first
- const bool bSwitchH2V = rInf.GetFrm() && rInf.GetFrm()->IsVertical();
- const bool bSwitchL2R = rInf.GetFrm() && rInf.GetFrm()->IsRightToLeft() &&
- ! rInf.IsIgnoreFrmRTL();
+ const bool bSwitchH2V = rInf.GetFrame() && rInf.GetFrame()->IsVertical();
+ const bool bSwitchL2R = rInf.GetFrame() && rInf.GetFrame()->IsRightToLeft() &&
+ ! rInf.IsIgnoreFrameRTL();
const ComplexTextLayoutMode nMode = rInf.GetOut().GetLayoutMode();
const bool bBidiPor = ( bSwitchL2R !=
( TEXT_LAYOUT_DEFAULT != ( TEXT_LAYOUT_BIDI_RTL & nMode ) ) );
@@ -897,7 +897,7 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
nPixWidth = rInf.GetOut().PixelToLogic( aTmp ).Width();
}
- aTextOriginPos.X() += rInf.GetFrm()->IsRightToLeft() ? 0 : nPixWidth;
+ aTextOriginPos.X() += rInf.GetFrame()->IsRightToLeft() ? 0 : nPixWidth;
}
Color aOldColor( pTmpFont->GetColor() );
@@ -912,10 +912,10 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
// ASIAN LINE AND CHARACTER GRID MODE START
- if ( rInf.GetFrm() && rInf.SnapToGrid() && rInf.GetFont() &&
+ if ( rInf.GetFrame() && rInf.SnapToGrid() && rInf.GetFont() &&
SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
// ASIAN LINE AND CHARACTER GRID MODE: Do we want to snap asian characters to the grid?
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && pGrid->IsSnapToChars())
@@ -1012,7 +1012,7 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
aTextOriginPos.X() + rInf.GetPos().X() ;
if ( bSwitchH2V )
- rInf.GetFrm()->SwitchHorizontalToVertical( aTextOriginPos );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aTextOriginPos );
rInf.GetOut().DrawTextArray( aTextOriginPos, rInf.GetText(),
pKernArray, rInf.GetIdx(), rInf.GetLen() );
@@ -1025,10 +1025,10 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
// For text grid refactor
// ASIAN LINE AND CHARACTER GRID MODE START: not snap to characters
- if ( rInf.GetFrm() && rInf.SnapToGrid() && rInf.GetFont() &&
+ if ( rInf.GetFrame() && rInf.SnapToGrid() && rInf.GetFont() &&
SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
// ASIAN LINE AND CHARACTER GRID MODE - do not snap to characters
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && !pGrid->IsSnapToChars() )
@@ -1044,7 +1044,7 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
rInf.GetOut().GetTextArray( rInf.GetText(), pKernArray,
rInf.GetIdx(), rInf.GetLen() );
if ( bSwitchH2V )
- rInf.GetFrm()->SwitchHorizontalToVertical( aTextOriginPos );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aTextOriginPos );
if ( rInf.GetSpace() || rInf.GetKanaComp())
{
long nSpaceAdd = rInf.GetSpace() / SPACING_PRECISION_FACTOR;
@@ -1169,10 +1169,10 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
&& ( aTmp != rInf.GetOut().GetMapMode().GetScaleX() );
if ( bSwitchL2R )
- rInf.GetFrm()->SwitchLTRtoRTL( aTextOriginPos );
+ rInf.GetFrame()->SwitchLTRtoRTL( aTextOriginPos );
if ( bSwitchH2V )
- rInf.GetFrm()->SwitchHorizontalToVertical( aTextOriginPos );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aTextOriginPos );
// In the good old days we used to have a simple DrawText if the
// output device is the printer. Now we need a DrawTextArray if
@@ -1559,10 +1559,10 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
( rInf.GetSpace() / SPACING_PRECISION_FACTOR );
if ( bSwitchL2R )
- rInf.GetFrm()->SwitchLTRtoRTL( aTextOriginPos );
+ rInf.GetFrame()->SwitchLTRtoRTL( aTextOriginPos );
if ( bSwitchH2V )
- rInf.GetFrm()->SwitchHorizontalToVertical( aTextOriginPos );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aTextOriginPos );
#if defined(MACOSX) || defined(IOS)
rInf.GetOut().DrawTextArray( aTextOriginPos, rInf.GetText(),
@@ -1701,14 +1701,14 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
if ( bSwitchL2R )
{
- rInf.GetFrm()->SwitchLTRtoRTL( aCurrPos );
- rInf.GetFrm()->SwitchLTRtoRTL( aEnd );
+ rInf.GetFrame()->SwitchLTRtoRTL( aCurrPos );
+ rInf.GetFrame()->SwitchLTRtoRTL( aEnd );
}
if ( bSwitchH2V )
{
- rInf.GetFrm()->SwitchHorizontalToVertical( aCurrPos );
- rInf.GetFrm()->SwitchHorizontalToVertical( aEnd );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aCurrPos );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aEnd );
}
rInf.GetOut().DrawWaveLine( aCurrPos, aEnd );
@@ -1749,10 +1749,10 @@ void SwFntObj::DrawText( SwDrawTextInfo &rInf )
{
if ( bSwitchL2R )
- rInf.GetFrm()->SwitchLTRtoRTL( aTextOriginPos );
+ rInf.GetFrame()->SwitchLTRtoRTL( aTextOriginPos );
if ( bSwitchH2V )
- rInf.GetFrm()->SwitchHorizontalToVertical( aTextOriginPos );
+ rInf.GetFrame()->SwitchHorizontalToVertical( aTextOriginPos );
#if defined(MACOSX) || defined(IOS)
rInf.GetOut().DrawTextArray( aTextOriginPos, *pStr, pKernArray + nOffs,
@@ -1811,10 +1811,10 @@ Size SwFntObj::GetTextSize( SwDrawTextInfo& rInf )
pPrinter->SetDigitLanguage( rInf.GetOut().GetDigitLanguage() );
}
- if ( rInf.GetFrm() && nLn && rInf.SnapToGrid() && rInf.GetFont() &&
+ if ( rInf.GetFrame() && nLn && rInf.SnapToGrid() && rInf.GetFont() &&
SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && pGrid->IsSnapToChars() )
{
const SwDoc* pDoc = rInf.GetShell()->GetDoc();
@@ -1853,10 +1853,10 @@ Size SwFntObj::GetTextSize( SwDrawTextInfo& rInf )
}
//for textgrid refactor
- if ( rInf.GetFrm() && nLn && rInf.SnapToGrid() && rInf.GetFont() &&
+ if ( rInf.GetFrame() && nLn && rInf.SnapToGrid() && rInf.GetFont() &&
SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && !pGrid->IsSnapToChars() )
{
const long nGridWidthAdd = EvalGridWidthAdd( pGrid, rInf );
@@ -1998,7 +1998,7 @@ Size SwFntObj::GetTextSize( SwDrawTextInfo& rInf )
return aTextSize;
}
-sal_Int32 SwFntObj::GetCrsrOfst( SwDrawTextInfo &rInf )
+sal_Int32 SwFntObj::GetCursorOfst( SwDrawTextInfo &rInf )
{
long nSpaceAdd = rInf.GetSpace() / SPACING_PRECISION_FACTOR;
const long nSperren = -rInf.GetSperren() / SPACING_PRECISION_FACTOR;
@@ -2092,10 +2092,10 @@ sal_Int32 SwFntObj::GetCrsrOfst( SwDrawTextInfo &rInf )
long nSpaceSum = 0;
long nKernSum = 0;
- if ( rInf.GetFrm() && rInf.GetLen() && rInf.SnapToGrid() &&
+ if ( rInf.GetFrame() && rInf.GetLen() && rInf.SnapToGrid() &&
rInf.GetFont() && SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && pGrid->IsSnapToChars() )
{
const SwDoc* pDoc = rInf.GetShell()->GetDoc();
@@ -2119,10 +2119,10 @@ sal_Int32 SwFntObj::GetCrsrOfst( SwDrawTextInfo &rInf )
}
//for textgrid refactor
- if ( rInf.GetFrm() && rInf.GetLen() && rInf.SnapToGrid() &&
+ if ( rInf.GetFrame() && rInf.GetLen() && rInf.SnapToGrid() &&
rInf.GetFont() && SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && !pGrid->IsSnapToChars() )
{
@@ -2328,10 +2328,10 @@ sal_Int32 SwFont::GetTextBreak( SwDrawTextInfo& rInf, long nTextWidth )
sal_Int32 nLn = rInf.GetLen() == COMPLETE_STRING
? rInf.GetText().getLength() : rInf.GetLen();
- if ( rInf.GetFrm() && nLn && rInf.SnapToGrid() &&
+ if ( rInf.GetFrame() && nLn && rInf.SnapToGrid() &&
rInf.GetFont() && SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && pGrid->IsSnapToChars() )
{
const SwDoc* pDoc = rInf.GetShell()->GetDoc();
@@ -2362,10 +2362,10 @@ sal_Int32 SwFont::GetTextBreak( SwDrawTextInfo& rInf, long nTextWidth )
}
//for text grid enhancement
- if ( rInf.GetFrm() && nLn && rInf.SnapToGrid() && rInf.GetFont() &&
+ if ( rInf.GetFrame() && nLn && rInf.SnapToGrid() && rInf.GetFont() &&
SW_CJK == rInf.GetFont()->GetActual() )
{
- SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrm()->FindPageFrm()));
+ SwTextGridItem const*const pGrid(GetGridItem(rInf.GetFrame()->FindPageFrame()));
if ( pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && !pGrid->IsSnapToChars() )
{
const long nGridWidthAdd = EvalGridWidthAdd( pGrid, rInf );
@@ -2545,7 +2545,7 @@ bool SwDrawTextInfo::ApplyAutoColor( vcl::Font* pFont )
/// OD 21.08.2002 #99657#
/// There is a user defined setting for the background, if there
/// is a background brush and its color is *not* "no fill"/"auto fill".
- if( GetFrm()->GetBackgroundBrush( aFillAttributes, pItem, pCol, aOrigBackRect, false ) )
+ if( GetFrame()->GetBackgroundBrush( aFillAttributes, pItem, pCol, aOrigBackRect, false ) )
{
if (aFillAttributes.get() && aFillAttributes->isUsed())
{
diff --git a/sw/source/core/txtnode/fntcap.cxx b/sw/source/core/txtnode/fntcap.cxx
index aabaeedd4b7a..55853b6bf5f3 100644
--- a/sw/source/core/txtnode/fntcap.cxx
+++ b/sw/source/core/txtnode/fntcap.cxx
@@ -276,11 +276,11 @@ void SwDoDrawCapital::DrawSpace( Point &rPos )
long nDiff = rInf.GetPos().X() - rPos.X();
Point aPos( rPos );
- const bool bSwitchL2R = rInf.GetFrm()->IsRightToLeft() &&
- ! rInf.IsIgnoreFrmRTL();
+ const bool bSwitchL2R = rInf.GetFrame()->IsRightToLeft() &&
+ ! rInf.IsIgnoreFrameRTL();
if ( bSwitchL2R )
- rInf.GetFrm()->SwitchLTRtoRTL( aPos );
+ rInf.GetFrame()->SwitchLTRtoRTL( aPos );
const ComplexTextLayoutMode nMode = rInf.GetpOut()->GetLayoutMode();
const bool bBidiPor = ( bSwitchL2R !=
@@ -289,8 +289,8 @@ void SwDoDrawCapital::DrawSpace( Point &rPos )
if ( bBidiPor )
nDiff = -nDiff;
- if ( rInf.GetFrm()->IsVertical() )
- rInf.GetFrm()->SwitchHorizontalToVertical( aPos );
+ if ( rInf.GetFrame()->IsVertical() )
+ rInf.GetFrame()->SwitchHorizontalToVertical( aPos );
if ( nDiff )
{
@@ -312,38 +312,38 @@ void SwSubFont::DrawCapital( SwDrawTextInfo &rInf )
DoOnCapitals( aDo );
}
-class SwDoCapitalCrsrOfst : public SwDoCapitals
+class SwDoCapitalCursorOfst : public SwDoCapitals
{
protected:
SwFntObj *pUpperFnt;
SwFntObj *pLowerFnt;
- sal_Int32 nCrsr;
+ sal_Int32 nCursor;
sal_uInt16 nOfst;
public:
- SwDoCapitalCrsrOfst( SwDrawTextInfo &rInfo, const sal_uInt16 nOfs ) :
- SwDoCapitals( rInfo ), pUpperFnt(nullptr), pLowerFnt(nullptr), nCrsr( 0 ), nOfst( nOfs )
+ SwDoCapitalCursorOfst( SwDrawTextInfo &rInfo, const sal_uInt16 nOfs ) :
+ SwDoCapitals( rInfo ), pUpperFnt(nullptr), pLowerFnt(nullptr), nCursor( 0 ), nOfst( nOfs )
{ }
- virtual ~SwDoCapitalCrsrOfst() {}
+ virtual ~SwDoCapitalCursorOfst() {}
virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont ) override;
virtual void Do() override;
- inline sal_Int32 GetCrsr(){ return nCrsr; }
+ inline sal_Int32 GetCursor(){ return nCursor; }
};
-void SwDoCapitalCrsrOfst::Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont )
+void SwDoCapitalCursorOfst::Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont )
{
pUpperFnt = pUpperFont;
pLowerFnt = pLowerFont;
}
-void SwDoCapitalCrsrOfst::Do()
+void SwDoCapitalCursorOfst::Do()
{
if ( nOfst )
{
if ( static_cast<long>(nOfst) > rInf.GetSize().Width() )
{
nOfst -= rInf.GetSize().Width();
- nCrsr = nCrsr + rInf.GetLen();
+ nCursor = nCursor + rInf.GetLen();
}
else
{
@@ -355,35 +355,35 @@ void SwDoCapitalCrsrOfst::Do()
aDrawInf.SetOfst( nOfst );
aDrawInf.SetKern( rInf.GetKern() );
aDrawInf.SetKanaComp( rInf.GetKanaComp() );
- aDrawInf.SetFrm( rInf.GetFrm() );
+ aDrawInf.SetFrame( rInf.GetFrame() );
aDrawInf.SetFont( rInf.GetFont() );
if ( rInf.GetUpper() )
{
aDrawInf.SetSpace( 0 );
- nCrsr = nCrsr + pUpperFnt->GetCrsrOfst( aDrawInf );
+ nCursor = nCursor + pUpperFnt->GetCursorOfst( aDrawInf );
}
else
{
aDrawInf.SetSpace( rInf.GetSpace() );
- nCrsr = nCrsr + pLowerFnt->GetCrsrOfst( aDrawInf );
+ nCursor = nCursor + pLowerFnt->GetCursorOfst( aDrawInf );
}
nOfst = 0;
}
}
}
-sal_Int32 SwSubFont::GetCapitalCrsrOfst( SwDrawTextInfo& rInf )
+sal_Int32 SwSubFont::GetCapitalCursorOfst( SwDrawTextInfo& rInf )
{
const long nOldKern = rInf.GetKern();
rInf.SetKern( CheckKerning() );
- SwDoCapitalCrsrOfst aDo( rInf, rInf.GetOfst() );
+ SwDoCapitalCursorOfst aDo( rInf, rInf.GetOfst() );
Point aPos;
rInf.SetPos( aPos );
rInf.SetDrawSpace( false );
DoOnCapitals( aDo );
rInf.SetKern( nOldKern );
- return aDo.GetCrsr();
+ return aDo.GetCursor();
}
class SwDoDrawStretchCapital : public SwDoDrawCapital
@@ -425,14 +425,14 @@ void SwDoDrawStretchCapital::Do()
rInf.ApplyAutoColor();
Point aPos( rInf.GetPos() );
- const bool bSwitchL2R = rInf.GetFrm()->IsRightToLeft() &&
- ! rInf.IsIgnoreFrmRTL();
+ const bool bSwitchL2R = rInf.GetFrame()->IsRightToLeft() &&
+ ! rInf.IsIgnoreFrameRTL();
if ( bSwitchL2R )
- rInf.GetFrm()->SwitchLTRtoRTL( aPos );
+ rInf.GetFrame()->SwitchLTRtoRTL( aPos );
- if ( rInf.GetFrm()->IsVertical() )
- rInf.GetFrm()->SwitchHorizontalToVertical( aPos );
+ if ( rInf.GetFrame()->IsVertical() )
+ rInf.GetFrame()->SwitchHorizontalToVertical( aPos );
// Optimierung:
if( 1 >= rInf.GetLen() )
diff --git a/sw/source/core/txtnode/swfont.cxx b/sw/source/core/txtnode/swfont.cxx
index 5a9dec06c0c6..134cce58364f 100644
--- a/sw/source/core/txtnode/swfont.cxx
+++ b/sw/source/core/txtnode/swfont.cxx
@@ -1328,13 +1328,13 @@ void SwSubFont::_DrawStretchText( SwDrawTextInfo &rInf )
{
SV_STAT( nDrawStretchText );
- if ( rInf.GetFrm() )
+ if ( rInf.GetFrame() )
{
- if ( rInf.GetFrm()->IsRightToLeft() )
- rInf.GetFrm()->SwitchLTRtoRTL( aPos );
+ if ( rInf.GetFrame()->IsRightToLeft() )
+ rInf.GetFrame()->SwitchLTRtoRTL( aPos );
- if ( rInf.GetFrm()->IsVertical() )
- rInf.GetFrm()->SwitchHorizontalToVertical( aPos );
+ if ( rInf.GetFrame()->IsVertical() )
+ rInf.GetFrame()->SwitchHorizontalToVertical( aPos );
rInf.SetPos( aPos );
}
@@ -1373,7 +1373,7 @@ void SwSubFont::_DrawStretchText( SwDrawTextInfo &rInf )
rInf.SetPos(aOldPos);
}
-sal_Int32 SwSubFont::_GetCrsrOfst( SwDrawTextInfo& rInf )
+sal_Int32 SwSubFont::_GetCursorOfst( SwDrawTextInfo& rInf )
{
if ( !pLastFont || pLastFont->GetOwner()!=m_pMagic )
ChgFnt( rInf.GetShell(), rInf.GetOut() );
@@ -1383,9 +1383,9 @@ sal_Int32 SwSubFont::_GetCrsrOfst( SwDrawTextInfo& rInf )
sal_Int32 nLn = rInf.GetLen() == COMPLETE_STRING ? rInf.GetText().getLength()
: rInf.GetLen();
rInf.SetLen( nLn );
- sal_Int32 nCrsr = 0;
+ sal_Int32 nCursor = 0;
if( IsCapital() && nLn )
- nCrsr = GetCapitalCrsrOfst( rInf );
+ nCursor = GetCapitalCursorOfst( rInf );
else
{
const OUString oldText = rInf.GetText();
@@ -1393,17 +1393,17 @@ sal_Int32 SwSubFont::_GetCrsrOfst( SwDrawTextInfo& rInf )
rInf.SetKern( CheckKerning() );
SV_STAT( nGetTextSize );
if ( !IsCaseMap() )
- nCrsr = pLastFont->GetCrsrOfst( rInf );
+ nCursor = pLastFont->GetCursorOfst( rInf );
else
{
OUString aTmp = CalcCaseMap( rInf.GetText() );
rInf.SetText( aTmp );
- nCrsr = pLastFont->GetCrsrOfst( rInf );
+ nCursor = pLastFont->GetCursorOfst( rInf );
}
rInf.SetKern( nOldKern );
rInf.SetText(oldText);
}
- return nCrsr;
+ return nCursor;
}
void SwSubFont::CalcEsc( SwDrawTextInfo& rInf, Point& rPos )
@@ -1411,7 +1411,7 @@ void SwSubFont::CalcEsc( SwDrawTextInfo& rInf, Point& rPos )
long nOfst;
const sal_uInt16 nDir = UnMapDirection(
- GetOrientation(), rInf.GetFrm() && rInf.GetFrm()->IsVertical() );
+ GetOrientation(), rInf.GetFrame() && rInf.GetFrame()->IsVertical() );
switch ( GetEscapement() )
{
@@ -1478,12 +1478,12 @@ void SwDrawTextInfo::Shift( sal_uInt16 nDir )
OSL_ENSURE( m_bSize, "DrawTextInfo: Undefined Width" );
#endif
- const bool bBidiPor = ( GetFrm() && GetFrm()->IsRightToLeft() ) !=
+ const bool bBidiPor = ( GetFrame() && GetFrame()->IsRightToLeft() ) !=
( TEXT_LAYOUT_DEFAULT != ( TEXT_LAYOUT_BIDI_RTL & GetpOut()->GetLayoutMode() ) );
nDir = bBidiPor ?
1800 :
- UnMapDirection( nDir, GetFrm() && GetFrm()->IsVertical() );
+ UnMapDirection( nDir, GetFrame() && GetFrame()->IsVertical() );
switch ( nDir )
{
diff --git a/sw/source/core/txtnode/thints.cxx b/sw/source/core/txtnode/thints.cxx
index f2cd6003507b..986a98532eee 100644
--- a/sw/source/core/txtnode/thints.cxx
+++ b/sw/source/core/txtnode/thints.cxx
@@ -1270,7 +1270,7 @@ bool SwTextNode::InsertHint( SwTextAttr * const pAttr, const SetAttrMode nMode )
if( !(SetAttrMode::NOTXTATRCHR & nInsMode) )
{
// Wir muessen zuerst einfuegen, da in SetAnchor()
- // dem FlyFrm GetStart() uebermittelt wird.
+ // dem FlyFrame GetStart() uebermittelt wird.
//JP 11.05.98: falls das Anker-Attribut schon richtig
// gesetzt ist, dann korrigiere dieses nach dem Einfuegen
// des Zeichens. Sonst muesste das immer ausserhalb
@@ -1397,7 +1397,7 @@ bool SwTextNode::InsertHint( SwTextAttr * const pAttr, const SetAttrMode nMode )
{
SwContentNode* pCNd = rNodes[ nSttIdx ]->GetContentNode();
if( nullptr != pCNd )
- pCNd->DelFrms();
+ pCNd->DelFrames();
}
}
diff --git a/sw/source/core/txtnode/atrflyin.cxx b/sw/source/core/txtnode/atrflyin.cxx
index d1f746bdfbb6..fb768e7538eb 100644
--- a/sw/source/core/txtnode/atrflyin.cxx
+++ b/sw/source/core/txtnode/atrflyin.cxx
@@ -76,20 +76,20 @@ SwTextFlyCnt::SwTextFlyCnt( SwFormatFlyCnt& rAttr, sal_Int32 nStartPos )
* Nodeinformationen vorliegen), verteilt sich der Ablauf.
* ad 1) MakeTextHint() wird durch den Aufruf von SwDoc::CopyLayout()
* der das neue FlyFrameFormat erzeugt und mit dem duplizierten Inhalt des
- * FlyFrm verbunden.
+ * FlyFrame verbunden.
* ad 2) SetAnchor() wird von SwTextNode::Insert() gerufen und sorgt fuer das
* setzen des Ankers (die SwPosition des Dummy-Zeichens wird dem FlyFrameFormat
* per SetAttr bekannt gegeben). Dies kann nicht im MakeTextHint erledigt
* werden, da der Zielnode unbestimmt ist.
* ad 3) _GetFlyFrm() wird im Formatierungsprozess vom LineIter gerufen
* und sucht den FlyFrm zum Dummyzeichen des aktuellen ContentFrm. Wird keiner
* gefunden, so wird ein neuer FlyFrm angelegt.
* Kritisch an diesem Vorgehen ist, dass das pContent->AppendFly() eine
* sofortige Neuformatierung von pContent anstoesst. Die Rekursion kommt
* allerdings durch den Lockmechanismus in SwTextFrm::Format() nicht
* zu stande.
* Attraktiv ist der Umstand, dass niemand ueber die vom Node abhaengigen
* ContentFrms iterieren braucht, um die FlyInCntFrm anzulegen. Dies geschieht
* bei der Arbeit.
*/
@@ -167,12 +167,12 @@ void SwTextFlyCnt::SetAnchor( const SwTextNode *pNode )
aAnchor.SetType( FLY_AS_CHAR ); // default!
aAnchor.SetAnchor( &aPos );
// beim Ankerwechsel werden immer alle FlyFrms vom Attribut geloescht
// JP 25.04.95: wird innerhalb des SplitNodes die Frames verschoben
// koennen die Frames erhalten bleiben.
if( ( !pNode->GetpSwpHints() || !pNode->GetpSwpHints()->IsInSplitNode() )
&& RES_DRAWFRMFMT != pFormat->Which() )
- pFormat->DelFrms();
+ pFormat->DelFrames();
// stehen wir noch im falschen Dokument ?
if( pDoc != pFormat->GetDoc() )
@@ -204,59 +204,59 @@ void SwTextFlyCnt::SetAnchor( const SwTextNode *pNode )
pFormat->SetFormatAttr( aAnchor ); // nur den Anker neu setzen
}
// Am Node haengen u.a. abhaengige CntFrms.
// Fuer jeden CntFrm wird ein SwFlyInCntFrm angelegt.
}
// _GetFlyFrm() wird im Formatierungsprozess vom LineIter gerufen
// und sucht den FlyFrm zum Dummyzeichen des aktuellen ContentFrm. Wird keiner
// gefunden, so wird ein neuer FlyFrm angelegt.
// (siehe Kommentar ind SwTextFlyCnt::MakeTextHint)
-SwFlyInCntFrm *SwTextFlyCnt::_GetFlyFrm( const SwFrm *pCurrFrm )
+SwFlyInContentFrame *SwTextFlyCnt::_GetFlyFrame( const SwFrame *pCurrFrame )
{
SwFrameFormat* pFrameFormat = GetFlyCnt().GetFrameFormat();
if( RES_DRAWFRMFMT == pFrameFormat->Which() )
{
- OSL_ENSURE( false, "SwTextFlyCnt::_GetFlyFrm: DrawInCnt-Baustelle!" );
+ OSL_ENSURE( false, "SwTextFlyCnt::_GetFlyFrame: DrawInCnt-Baustelle!" );
return nullptr;
}
- SwIterator<SwFlyFrm,SwFormat> aIter( *GetFlyCnt().pFormat );
- OSL_ENSURE( pCurrFrm->IsTextFrm(), "SwTextFlyCnt::_GetFlyFrm for TextFrms only." );
- SwFrm* pFrm = aIter.First();
- if ( pFrm )
+ SwIterator<SwFlyFrame,SwFormat> aIter( *GetFlyCnt().pFormat );
+ OSL_ENSURE( pCurrFrame->IsTextFrame(), "SwTextFlyCnt::_GetFlyFrame for TextFrames only." );
+ SwFrame* pFrame = aIter.First();
+ if ( pFrame )
{
- SwTextFrm *pFirst = const_cast<SwTextFrm*>(static_cast<const SwTextFrm*>(pCurrFrm));
+ SwTextFrame *pFirst = const_cast<SwTextFrame*>(static_cast<const SwTextFrame*>(pCurrFrame));
while ( pFirst->IsFollow() )
pFirst = pFirst->FindMaster();
do
{
- SwTextFrm *pTmp = pFirst;
+ SwTextFrame *pTmp = pFirst;
do
- { if( static_cast<SwFlyFrm*>(pFrm)->GetAnchorFrm() == static_cast<SwFrm*>(pTmp) )
+ { if( static_cast<SwFlyFrame*>(pFrame)->GetAnchorFrame() == static_cast<SwFrame*>(pTmp) )
{
- if ( pTmp != pCurrFrm )
+ if ( pTmp != pCurrFrame )
{
- pTmp->RemoveFly( static_cast<SwFlyFrm*>(pFrm) );
- const_cast<SwTextFrm*>(static_cast<const SwTextFrm*>(pCurrFrm))->AppendFly( static_cast<SwFlyFrm*>(pFrm) );
+ pTmp->RemoveFly( static_cast<SwFlyFrame*>(pFrame) );
+ const_cast<SwTextFrame*>(static_cast<const SwTextFrame*>(pCurrFrame))->AppendFly( static_cast<SwFlyFrame*>(pFrame) );
}
- return static_cast<SwFlyInCntFrm*>(pFrm);
+ return static_cast<SwFlyInContentFrame*>(pFrame);
}
pTmp = pTmp->GetFollow();
} while ( pTmp );
- pFrm = aIter.Next();
+ pFrame = aIter.Next();
- } while( pFrm );
+ } while( pFrame );
}
- // Wir haben keinen passenden FlyFrm gefunden, deswegen wird ein
+ // Wir haben keinen passenden FlyFrame gefunden, deswegen wird ein
// neuer angelegt.
// Dabei wird eine sofortige Neuformatierung von pCurrFrm angestossen.
// Die Rekursion wird durch den Lockmechanismus in SwTextFrm::Format()
// abgewuergt.
- SwFrm* pCurrentFrame = const_cast<SwFrm*>(pCurrFrm);
- SwFlyInCntFrm *pFly = new SwFlyInCntFrm(static_cast<SwFlyFrameFormat*>(pFrameFormat), pCurrentFrame, pCurrentFrame);
+ SwFrame* pCurrentFrame = const_cast<SwFrame*>(pCurrFrame);
+ SwFlyInContentFrame *pFly = new SwFlyInContentFrame(static_cast<SwFlyFrameFormat*>(pFrameFormat), pCurrentFrame, pCurrentFrame);
pCurrentFrame->AppendFly(pFly);
pFly->RegistFlys();
@@ -264,8 +264,8 @@ SwFlyInCntFrm *SwTextFlyCnt::_GetFlyFrm( const SwFrm *pCurrFrm )
// nach seiner Konstruktion stramm durchformatiert wird.
// #i26945# - Use new object formatter to format Writer
// fly frame and its content.
- SwObjectFormatter::FormatObj( *pFly, const_cast<SwFrm*>(pCurrFrm),
- pCurrFrm->FindPageFrm() );
+ SwObjectFormatter::FormatObj( *pFly, const_cast<SwFrame*>(pCurrFrame),
+ pCurrFrame->FindPageFrame() );
return pFly;
}
@@ -76,20 +76,20 @@ SwTextFlyCnt::SwTextFlyCnt( SwFormatFlyCnt& rAttr, sal_Int32 nStartPos )
* per SetAttr bekannt gegeben). Dies kann nicht im MakeTextHint erledigt
* werden, da der Zielnode unbestimmt ist.
- * ad 3) _GetFlyFrm() wird im Formatierungsprozess vom LineIter gerufen
- * und sucht den FlyFrm zum Dummyzeichen des aktuellen ContentFrm. Wird keiner
- * gefunden, so wird ein neuer FlyFrm angelegt.
+ * ad 3) _GetFlyFrame() wird im Formatierungsprozess vom LineIter gerufen
+ * und sucht den FlyFrame zum Dummyzeichen des aktuellen ContentFrame. Wird keiner
+ * gefunden, so wird ein neuer FlyFrame angelegt.
* Kritisch an diesem Vorgehen ist, dass das pContent->AppendFly() eine
* sofortige Neuformatierung von pContent anstoesst. Die Rekursion kommt
@@ -76,20 +76,20 @@ SwTextFlyCnt::SwTextFlyCnt( SwFormatFlyCnt& rAttr, sal_Int32 nStartPos )
* Kritisch an diesem Vorgehen ist, dass das pContent->AppendFly() eine
* sofortige Neuformatierung von pContent anstoesst. Die Rekursion kommt
- * allerdings durch den Lockmechanismus in SwTextFrm::Format() nicht
+ * allerdings durch den Lockmechanismus in SwTextFrame::Format() nicht
* zu stande.
* Attraktiv ist der Umstand, dass niemand ueber die vom Node abhaengigen
@@ -76,20 +76,20 @@ SwTextFlyCnt::SwTextFlyCnt( SwFormatFlyCnt& rAttr, sal_Int32 nStartPos )
* zu stande.
* Attraktiv ist der Umstand, dass niemand ueber die vom Node abhaengigen
- * ContentFrms iterieren braucht, um die FlyInCntFrm anzulegen. Dies geschieht
+ * ContentFrames iterieren braucht, um die FlyInContentFrame anzulegen. Dies geschieht
* bei der Arbeit.
*/
@@ -167,12 +167,12 @@ void SwTextFlyCnt::SetAnchor( const SwTextNode *pNode )
aAnchor.SetType( FLY_AS_CHAR ); // default!
aAnchor.SetAnchor( &aPos );
- // beim Ankerwechsel werden immer alle FlyFrms vom Attribut geloescht
+ // beim Ankerwechsel werden immer alle FlyFrames vom Attribut geloescht
// JP 25.04.95: wird innerhalb des SplitNodes die Frames verschoben
// koennen die Frames erhalten bleiben.
@@ -204,59 +204,59 @@ void SwTextFlyCnt::SetAnchor( const SwTextNode *pNode )
pFormat->SetFormatAttr( aAnchor ); // nur den Anker neu setzen
}
- // Am Node haengen u.a. abhaengige CntFrms.
- // Fuer jeden CntFrm wird ein SwFlyInCntFrm angelegt.
+ // Am Node haengen u.a. abhaengige ContentFrames.
+ // Fuer jeden ContentFrame wird ein SwFlyInContentFrame angelegt.
}
@@ -204,59 +204,59 @@ void SwTextFlyCnt::SetAnchor( const SwTextNode *pNode )
}
-// _GetFlyFrm() wird im Formatierungsprozess vom LineIter gerufen
-// und sucht den FlyFrm zum Dummyzeichen des aktuellen ContentFrm. Wird keiner
-// gefunden, so wird ein neuer FlyFrm angelegt.
+// _GetFlyFrame() wird im Formatierungsprozess vom LineIter gerufen
+// und sucht den FlyFrame zum Dummyzeichen des aktuellen ContentFrame. Wird keiner
+// gefunden, so wird ein neuer FlyFrame angelegt.
// (siehe Kommentar ind SwTextFlyCnt::MakeTextHint)
@@ -204,59 +204,59 @@ void SwTextFlyCnt::SetAnchor( const SwTextNode *pNode )
// neuer angelegt.
- // Dabei wird eine sofortige Neuformatierung von pCurrFrm angestossen.
- // Die Rekursion wird durch den Lockmechanismus in SwTextFrm::Format()
+ // Dabei wird eine sofortige Neuformatierung von pCurrFrame angestossen.
+ // Die Rekursion wird durch den Lockmechanismus in SwTextFrame::Format()
// abgewuergt.
diff --git a/sw/source/core/txtnode/atrftn.cxx b/sw/source/core/txtnode/atrftn.cxx
index 9f74feb41b73..3bbf8720c5aa 100644
--- a/sw/source/core/txtnode/atrftn.cxx
+++ b/sw/source/core/txtnode/atrftn.cxx
@@ -165,7 +165,7 @@ void SwFormatFootnote::SetEndNote( bool b )
{
if ( GetTextFootnote() )
{
- GetTextFootnote()->DelFrms(nullptr);
+ GetTextFootnote()->DelFrames(nullptr);
}
m_bEndNote = b;
}
@@ -307,9 +307,9 @@ void SwTextFootnote::SetStartNode( const SwNodeIndex *pNewNode, bool bDelNode )
}
else
// Werden die Nodes nicht geloescht mussen sie bei den Seiten
// abmeldet (Frms loeschen) werden, denn sonst bleiben sie
// stehen (Undo loescht sie nicht!)
- DelFrms( nullptr );
+ DelFrames( nullptr );
}
DELETEZ( m_pStartNode );
@@ -431,58 +431,58 @@ void SwTextFootnote::MakeNewTextSection( SwNodes& rNodes )
m_pStartNode = new SwNodeIndex( *pSttNd );
}
-void SwTextFootnote::DelFrms( const SwFrm* pSib )
+void SwTextFootnote::DelFrames( const SwFrame* pSib )
{
// delete the FootnoteFrames from the pages
OSL_ENSURE( m_pTextNode, "SwTextFootnote: where is my TextNode?" );
if ( !m_pTextNode )
return;
- const SwRootFrm* pRoot = pSib ? pSib->getRootFrm() : nullptr;
- bool bFrmFnd = false;
+ const SwRootFrame* pRoot = pSib ? pSib->getRootFrame() : nullptr;
+ bool bFrameFnd = false;
{
- SwIterator<SwContentFrm,SwTextNode> aIter( *m_pTextNode );
- for( SwContentFrm* pFnd = aIter.First(); pFnd; pFnd = aIter.Next() )
+ SwIterator<SwContentFrame,SwTextNode> aIter( *m_pTextNode );
+ for( SwContentFrame* pFnd = aIter.First(); pFnd; pFnd = aIter.Next() )
{
- if( pRoot != pFnd->getRootFrm() && pRoot )
+ if( pRoot != pFnd->getRootFrame() && pRoot )
continue;
- SwPageFrm* pPage = pFnd->FindPageFrm();
+ SwPageFrame* pPage = pFnd->FindPageFrame();
if( pPage )
{
pPage->RemoveFootnote( pFnd, this );
- bFrmFnd = true;
+ bFrameFnd = true;
}
}
}
//JP 13.05.97: falls das Layout vorm loeschen der Fussnoten entfernt
// wird, sollte man das ueber die Fussnote selbst tun
- if ( !bFrmFnd && m_pStartNode )
+ if ( !bFrameFnd && m_pStartNode )
{
SwNodeIndex aIdx( *m_pStartNode );
SwContentNode* pCNd = m_pTextNode->GetNodes().GoNext( &aIdx );
if( pCNd )
{
- SwIterator<SwContentFrm,SwContentNode> aIter( *pCNd );
- for( SwContentFrm* pFnd = aIter.First(); pFnd; pFnd = aIter.Next() )
+ SwIterator<SwContentFrame,SwContentNode> aIter( *pCNd );
+ for( SwContentFrame* pFnd = aIter.First(); pFnd; pFnd = aIter.Next() )
{
- if( pRoot != pFnd->getRootFrm() && pRoot )
+ if( pRoot != pFnd->getRootFrame() && pRoot )
continue;
- SwPageFrm* pPage = pFnd->FindPageFrm();
+ SwPageFrame* pPage = pFnd->FindPageFrame();
- SwFrm *pFrm = pFnd->GetUpper();
- while ( pFrm && !pFrm->IsFootnoteFrm() )
- pFrm = pFrm->GetUpper();
+ SwFrame *pFrame = pFnd->GetUpper();
+ while ( pFrame && !pFrame->IsFootnoteFrame() )
+ pFrame = pFrame->GetUpper();
- SwFootnoteFrm *pFootnote = static_cast<SwFootnoteFrm*>(pFrm);
+ SwFootnoteFrame *pFootnote = static_cast<SwFootnoteFrame*>(pFrame);
while ( pFootnote && pFootnote->GetMaster() )
pFootnote = pFootnote->GetMaster();
OSL_ENSURE( pFootnote->GetAttr() == this, "Footnote mismatch error." );
while ( pFootnote )
{
- SwFootnoteFrm *pFoll = pFootnote->GetFollow();
+ SwFootnoteFrame *pFoll = pFootnote->GetFollow();
pFootnote->Cut();
- SwFrm::DestroyFrm(pFootnote);
+ SwFrame::DestroyFrame(pFootnote);
pFootnote = pFoll;
}
@@ -307,9 +307,9 @@ void SwTextFootnote::SetStartNode( const SwNodeIndex *pNewNode, bool bDelNode )
else
// Werden die Nodes nicht geloescht mussen sie bei den Seiten
- // abmeldet (Frms loeschen) werden, denn sonst bleiben sie
+ // abmeldet (Frames loeschen) werden, denn sonst bleiben sie
// stehen (Undo loescht sie nicht!)
diff --git a/sw/source/core/txtnode/ndtxt.cxx b/sw/source/core/txtnode/ndtxt.cxx
index 2d6bcd82a771..85a83660f4b5 100644
--- a/sw/source/core/txtnode/ndtxt.cxx
+++ b/sw/source/core/txtnode/ndtxt.cxx
@@ -103,7 +103,7 @@ typedef std::vector<SwTextAttr*> SwpHts;
pNd->GetpSwpHints()->Check(true); }
#define CHECK_SWPHINTS_IF_FRM(pNd) { if( pNd->GetpSwpHints() && \
!pNd->GetDoc()->IsInReading() ) \
- pNd->GetpSwpHints()->Check(getLayoutFrm(nullptr, nullptr, nullptr, false) != nullptr); }
+ pNd->GetpSwpHints()->Check(getLayoutFrame(nullptr, nullptr, nullptr, false) != nullptr); }
#else
#define CHECK_SWPHINTS(pNd)
#define CHECK_SWPHINTS_IF_FRM(pNd)
@@ -123,7 +123,7 @@ SwTextNode *SwNodes::MakeTextNode( const SwNodeIndex & rWhere,
if ( IsDocNodes() )
UpdateOutlineNode(*pNode);
- // if there is no layout or it is in a hidden section, MakeFrms is not needed
+ // if there is no layout or it is in a hidden section, MakeFrames is not needed
const SwSectionNode* pSectNd;
if( !GetDoc()->getIDocumentLayoutAccess().GetCurrentViewShell() ||
( nullptr != (pSectNd = pNode->FindSectionNode()) &&
@@ -140,7 +140,7 @@ SwTextNode *SwNodes::MakeTextNode( const SwNodeIndex & rWhere,
switch (pNd->GetNodeType())
{
case ND_TABLENODE:
- static_cast<SwTableNode*>(pNd)->MakeFrms( aIdx );
+ static_cast<SwTableNode*>(pNd)->MakeFrames( aIdx );
return pNode;
case ND_SECTIONNODE:
@@ -148,19 +148,19 @@ SwTextNode *SwNodes::MakeTextNode( const SwNodeIndex & rWhere,
static_cast<SwSectionNode*>(pNd)->IsContentHidden() )
{
SwNodeIndex aTmpIdx( *pNode );
- pNd = FindPrvNxtFrmNode( aTmpIdx, pNode );
+ pNd = FindPrvNxtFrameNode( aTmpIdx, pNode );
if( !pNd )
return pNode;
aTmp = *pNd;
break;
}
- static_cast<SwSectionNode*>(pNd)->MakeFrms( aIdx );
+ static_cast<SwSectionNode*>(pNd)->MakeFrames( aIdx );
return pNode;
case ND_TEXTNODE:
case ND_GRFNODE:
case ND_OLENODE:
- static_cast<SwContentNode*>(pNd)->MakeFrms( *pNode );
+ static_cast<SwContentNode*>(pNd)->MakeFrames( *pNode );
return pNode;
case ND_ENDNODE:
@@ -270,7 +270,7 @@ SwTextNode::~SwTextNode()
if (HasWriterListeners())
{
- DelFrms_TextNodePart();
+ DelFrames_TextNodePart();
}
}
@@ -282,13 +282,13 @@ void SwTextNode::FileLoadedInitHints()
}
}
-SwContentFrm *SwTextNode::MakeFrm( SwFrm* pSib )
+SwContentFrame *SwTextNode::MakeFrame( SwFrame* pSib )
{
// fdo#52028: ODF file import does not result in MergePortions being called
// for every attribute, since that would be inefficient. So call it here.
FileLoadedInitHints();
- SwContentFrm *pFrm = new SwTextFrm( this, pSib );
- return pFrm;
+ SwContentFrame *pFrame = new SwTextFrame( this, pSib );
+ return pFrame;
}
sal_Int32 SwTextNode::Len() const
@@ -302,20 +302,20 @@ static void lcl_ChangeFootnoteRef( SwTextNode &rNode )
SwpHints *pSwpHints = rNode.GetpSwpHints();
if( pSwpHints && rNode.GetDoc()->getIDocumentLayoutAccess().GetCurrentViewShell() )
{
- SwContentFrm* pFrm = nullptr;
+ SwContentFrame* pFrame = nullptr;
// OD 07.11.2002 #104840# - local variable to remember first footnote
// of node <rNode> in order to invalidate position of its first content.
// Thus, in its <MakeAll()> it will checked its position relative to its reference.
- SwFootnoteFrm* pFirstFootnoteOfNode = nullptr;
+ SwFootnoteFrame* pFirstFootnoteOfNode = nullptr;
for( size_t j = pSwpHints->Count(); j; )
{
SwTextAttr* pHt = pSwpHints->Get(--j);
if (RES_TXTATR_FTN == pHt->Which())
{
- if( !pFrm )
+ if( !pFrame )
{
- pFrm = SwIterator<SwContentFrm,SwTextNode>(rNode).First();
- if (!pFrm)
+ pFrame = SwIterator<SwContentFrame,SwTextNode>(rNode).First();
+ if (!pFrame)
return;
}
SwTextFootnote *pAttr = static_cast<SwTextFootnote*>(pHt);
@@ -323,18 +323,18 @@ static void lcl_ChangeFootnoteRef( SwTextNode &rNode )
SwNodeIndex aIdx( *pAttr->GetStartNode(), 1 );
SwContentNode *pNd = aIdx.GetNode().GetContentNode();
if ( !pNd )
- pNd = pFrm->GetAttrSet()->GetDoc()->
+ pNd = pFrame->GetAttrSet()->GetDoc()->
GetNodes().GoNextSection( &aIdx, true, false );
if ( !pNd )
continue;
- SwIterator<SwContentFrm,SwContentNode> aIter( *pNd );
- SwContentFrm* pContent = aIter.First();
+ SwIterator<SwContentFrame,SwContentNode> aIter( *pNd );
+ SwContentFrame* pContent = aIter.First();
if( pContent )
{
- OSL_ENSURE( pContent->getRootFrm() == pFrm->getRootFrm(),
+ OSL_ENSURE( pContent->getRootFrame() == pFrame->getRootFrame(),
"lcl_ChangeFootnoteRef: Layout double?" );
- SwFootnoteFrm *pFootnote = pContent->FindFootnoteFrm();
+ SwFootnoteFrame *pFootnote = pContent->FindFootnoteFrame();
if( pFootnote && pFootnote->GetAttr() == pAttr )
{
while( pFootnote->GetMaster() )
@@ -343,16 +343,16 @@ static void lcl_ChangeFootnoteRef( SwTextNode &rNode )
pFirstFootnoteOfNode = pFootnote;
while ( pFootnote )
{
- pFootnote->SetRef( pFrm );
+ pFootnote->SetRef( pFrame );
pFootnote = pFootnote->GetFollow();
- static_cast<SwTextFrm*>(pFrm)->SetFootnote( true );
+ static_cast<SwTextFrame*>(pFrame)->SetFootnote( true );
}
}
#if OSL_DEBUG_LEVEL > 0
while( nullptr != (pContent = aIter.Next()) )
{
- SwFootnoteFrm *pDbgFootnote = pContent->FindFootnoteFrm();
- OSL_ENSURE( !pDbgFootnote || pDbgFootnote->GetRef() == pFrm,
+ SwFootnoteFrame *pDbgFootnote = pContent->FindFootnoteFrame();
+ OSL_ENSURE( !pDbgFootnote || pDbgFootnote->GetRef() == pFrame,
"lcl_ChangeFootnoteRef: Who's that guy?" );
}
#endif
@@ -362,7 +362,7 @@ static void lcl_ChangeFootnoteRef( SwTextNode &rNode )
// #104840# - invalidate
if ( pFirstFootnoteOfNode )
{
- SwContentFrm* pContent = pFirstFootnoteOfNode->ContainsContent();
+ SwContentFrame* pContent = pFirstFootnoteOfNode->ContainsContent();
if ( pContent )
{
pContent->_InvalidatePos();
@@ -465,7 +465,7 @@ SwContentNode *SwTextNode::SplitContentNode( const SwPosition &rPos )
SwTextAttr* const pHt = m_pSwpHints->Get( --j );
if ( RES_TXTATR_FLYCNT == pHt ->Which() )
{
- pHt->GetFlyCnt().GetFrameFormat()->DelFrms();
+ pHt->GetFlyCnt().GetFrameFormat()->DelFrames();
}
else if ( pHt->DontExpand() )
{
@@ -482,17 +482,17 @@ SwContentNode *SwTextNode::SplitContentNode( const SwPosition &rPos )
}
- SwIterator<SwContentFrm,SwTextNode> aIter( *this );
- for( SwContentFrm* pFrm = aIter.First(); pFrm; pFrm = aIter.Next() )
+ SwIterator<SwContentFrame,SwTextNode> aIter( *this );
+ for( SwContentFrame* pFrame = aIter.First(); pFrame; pFrame = aIter.Next() )
{
- pFrm->RegisterToNode( *pNode );
- if( pFrm->IsTextFrm() && !pFrm->IsFollow() && static_cast<SwTextFrm*>(pFrm)->GetOfst() )
- static_cast<SwTextFrm*>(pFrm)->SetOfst( 0 );
+ pFrame->RegisterToNode( *pNode );
+ if( pFrame->IsTextFrame() && !pFrame->IsFollow() && static_cast<SwTextFrame*>(pFrame)->GetOfst() )
+ static_cast<SwTextFrame*>(pFrame)->SetOfst( 0 );
}
if ( IsInCache() )
{
- SwFrm::GetCache().Delete( this );
+ SwFrame::GetCache().Delete( this );
SetInCache( false );
}
@@ -501,10 +501,10 @@ SwContentNode *SwTextNode::SplitContentNode( const SwPosition &rPos )
// If there is an accessible layout we must call modify even
// with length zero, because we have to notify about the changed
// text node.
- const SwRootFrm *pRootFrm;
+ const SwRootFrame *pRootFrame;
if ( (nTextLen != nSplitPos) ||
- ( (pRootFrm = pNode->GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout()) != nullptr &&
- pRootFrm->IsAnyShellAccessible() ) )
+ ( (pRootFrame = pNode->GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout()) != nullptr &&
+ pRootFrame->IsAnyShellAccessible() ) )
{
// dann sage den Frames noch, das am Ende etwas "geloescht" wurde
if( 1 == nTextLen - nSplitPos )
@@ -522,7 +522,7 @@ SwContentNode *SwTextNode::SplitContentNode( const SwPosition &rPos )
{
MoveTextAttr_To_AttrSet();
}
- pNode->MakeFrms( *this ); // neue Frames anlegen.
+ pNode->MakeFrames( *this ); // neue Frames anlegen.
lcl_ChangeFootnoteRef( *this );
}
else
@@ -582,7 +582,7 @@ SwContentNode *SwTextNode::SplitContentNode( const SwPosition &rPos )
if ( HasWriterListeners() )
{
- MakeFrms( *pNode ); // neue Frames anlegen.
+ MakeFrames( *pNode ); // neue Frames anlegen.
}
lcl_ChangeFootnoteRef( *pNode );
}
@@ -709,7 +709,7 @@ SwContentNode *SwTextNode::JoinNext()
if( pTextNode->HasAnyIndex() )
{
- // alle Crsr/StkCrsr/UnoCrsr aus dem Loeschbereich verschieben
+ // alle Cursor/StackCursor/UnoCursor aus dem Loeschbereich verschieben
pDoc->CorrAbs( aIdx, SwPosition( *this ), nOldLen, true );
}
rNds.Delete(aIdx);
@@ -803,7 +803,7 @@ SwContentNode *SwTextNode::JoinPrev()
if( pTextNode->HasAnyIndex() )
{
- // alle Crsr/StkCrsr/UnoCrsr aus dem Loeschbereich verschieben
+ // alle Cursor/StackCursor/UnoCursor aus dem Loeschbereich verschieben
pDoc->CorrAbs( aIdx, SwPosition( *this ), nLen, true );
}
rNds.Delete(aIdx);
@@ -1182,8 +1182,8 @@ void SwTextNode::Update(
//Any drawing objects anchored into this text node may be sorted by their
//anchor position which may have changed here, so resort them
- SwContentFrm* pContentFrm = getLayoutFrm(GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout());
- SwSortedObjs* pSortedObjs = pContentFrm ? pContentFrm->GetDrawObjs() : nullptr;
+ SwContentFrame* pContentFrame = getLayoutFrame(GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout());
+ SwSortedObjs* pSortedObjs = pContentFrame ? pContentFrame->GetDrawObjs() : nullptr;
if (pSortedObjs)
pSortedObjs->UpdateAll();
}
@@ -1382,7 +1382,7 @@ const SwTextInputField* SwTextNode::GetOverlappingInputField( const SwTextAttr&
return pTextInputField;
}
-void SwTextNode::DelFrms_TextNodePart()
+void SwTextNode::DelFrames_TextNodePart()
{
SetWrong( nullptr );
SetWrongDirty(WrongState::TODO);
@@ -2382,7 +2382,7 @@ void SwTextNode::GCAttr()
if(bChanged)
{
- //TextFrm's reagieren auf aHint, andere auf aNew
+ //TextFrame's reagieren auf aHint, andere auf aNew
SwUpdateAttr aHint(
nMin,
nMax,
@@ -2453,13 +2453,13 @@ void SwTextNode::NumRuleChgd()
if( IsInCache() )
{
- SwFrm::GetCache().Delete( this );
+ SwFrame::GetCache().Delete( this );
SetInCache( false );
}
SetInSwFntCache( false );
// Sending "noop" modify in order to cause invalidations of registered
// <SwTextFrm> instances to get the list style change respectively the change
// in the list tree reflected in the layout.
// Important note:
{
@@ -2562,7 +2562,7 @@ SwTextNode* SwTextNode::_MakeNewTextNode( const SwNodeIndex& rPos, bool bNext,
if( !bNext && bRemoveFromCache && IsInCache() )
{
- SwFrm::GetCache().Delete( this );
+ SwFrame::GetCache().Delete( this );
SetInCache( false );
}
}
@@ -2607,7 +2607,7 @@ SwTextNode* SwTextNode::_MakeNewTextNode( const SwNodeIndex& rPos, bool bNext,
aClearWhichIds.push_back( RES_PARATR_NUMRULE );
if ( ClearItemsFromAttrSet( aClearWhichIds ) != 0 && IsInCache() )
{
- SwFrm::GetCache().Delete( this );
+ SwFrame::GetCache().Delete( this );
SetInCache( false );
}
}
@@ -2639,7 +2639,7 @@ SwContentNode* SwTextNode::AppendNode( const SwPosition & rPos )
}
if( HasWriterListeners() )
- MakeFrms( *pNew );
+ MakeFrames( *pNew );
return pNew;
}
@@ -2453,13 +2453,13 @@ void SwTextNode::NumRuleChgd()
SetInSwFntCache( false );
// Sending "noop" modify in order to cause invalidations of registered
- // <SwTextFrm> instances to get the list style change respectively the change
+ // <SwTextFrame> instances to get the list style change respectively the change
// in the list tree reflected in the layout.
// Important note:
diff --git a/sw/source/core/txtnode/txtedt.cxx b/sw/source/core/txtnode/txtedt.cxx
index e8e060f1b84a..5064e0081de9 100644
--- a/sw/source/core/txtnode/txtedt.cxx
+++ b/sw/source/core/txtnode/txtedt.cxx
@@ -88,10 +88,10 @@ using namespace ::com::sun::star::uno;
using namespace ::com::sun::star::linguistic2;
using namespace ::com::sun::star::smarttags;
-// Wir ersparen uns in Hyphenate ein GetFrm()
+// Wir ersparen uns in Hyphenate ein GetFrame()
// Achtung: in edlingu.cxx stehen die Variablen!
extern const SwTextNode *pLinguNode;
-extern SwTextFrm *pLinguFrm;
+extern SwTextFrame *pLinguFrame;
/*
* This has basically the same function as SwScriptInfo::MaskHiddenRanges,
@@ -177,32 +177,32 @@ lcl_MaskRedlinesAndHiddenText( const SwTextNode& rNode, OUStringBuffer& rText,
/**
* Used for spell checking. Calculates a rectangle for repaint.
*/
-static SwRect lcl_CalculateRepaintRect( SwTextFrm& rTextFrm, sal_Int32 nChgStart, sal_Int32 nChgEnd )
+static SwRect lcl_CalculateRepaintRect( SwTextFrame& rTextFrame, sal_Int32 nChgStart, sal_Int32 nChgEnd )
{
SwRect aRect;
- SwTextNode *pNode = rTextFrm.GetTextNode();
+ SwTextNode *pNode = rTextFrame.GetTextNode();
SwNodeIndex aNdIdx( *pNode );
SwPosition aPos( aNdIdx, SwIndex( pNode, nChgEnd ) );
- SwCrsrMoveState aTmpState( MV_NONE );
+ SwCursorMoveState aTmpState( MV_NONE );
aTmpState.m_b2Lines = true;
- rTextFrm.GetCharRect( aRect, aPos, &aTmpState );
+ rTextFrame.GetCharRect( aRect, aPos, &aTmpState );
// information about end of repaint area
Sw2LinesPos* pEnd2Pos = aTmpState.m_p2Lines;
- const SwTextFrm *pEndFrm = &rTextFrm;
+ const SwTextFrame *pEndFrame = &rTextFrame;
- while( pEndFrm->HasFollow() &&
- nChgEnd >= pEndFrm->GetFollow()->GetOfst() )
- pEndFrm = pEndFrm->GetFollow();
+ while( pEndFrame->HasFollow() &&
+ nChgEnd >= pEndFrame->GetFollow()->GetOfst() )
+ pEndFrame = pEndFrame->GetFollow();
if ( pEnd2Pos )
{
// we are inside a special portion, take left border
- SWRECTFN( pEndFrm )
+ SWRECTFN( pEndFrame )
(aRect.*fnRect->fnSetTop)( (pEnd2Pos->aLine.*fnRect->fnGetTop)() );
- if ( pEndFrm->IsRightToLeft() )
+ if ( pEndFrame->IsRightToLeft() )
(aRect.*fnRect->fnSetLeft)( (pEnd2Pos->aPortion.*fnRect->fnGetLeft)() );
else
(aRect.*fnRect->fnSetLeft)( (pEnd2Pos->aPortion.*fnRect->fnGetRight)() );
@@ -214,28 +214,28 @@ static SwRect lcl_CalculateRepaintRect( SwTextFrm& rTextFrm, sal_Int32 nChgStart
aTmpState.m_p2Lines = nullptr;
SwRect aTmp;
aPos = SwPosition( aNdIdx, SwIndex( pNode, nChgStart ) );
- rTextFrm.GetCharRect( aTmp, aPos, &aTmpState );
+ rTextFrame.GetCharRect( aTmp, aPos, &aTmpState );
// i63141: GetCharRect(..) could cause a formatting,
- // during the formatting SwTextFrms could be joined, deleted, created...
- // => we have to reinit pStartFrm and pEndFrm after the formatting
- const SwTextFrm* pStartFrm = &rTextFrm;
- while( pStartFrm->HasFollow() &&
- nChgStart >= pStartFrm->GetFollow()->GetOfst() )
- pStartFrm = pStartFrm->GetFollow();
- pEndFrm = pStartFrm;
- while( pEndFrm->HasFollow() &&
- nChgEnd >= pEndFrm->GetFollow()->GetOfst() )
- pEndFrm = pEndFrm->GetFollow();
+ // during the formatting SwTextFrames could be joined, deleted, created...
+ // => we have to reinit pStartFrame and pEndFrame after the formatting
+ const SwTextFrame* pStartFrame = &rTextFrame;
+ while( pStartFrame->HasFollow() &&
+ nChgStart >= pStartFrame->GetFollow()->GetOfst() )
+ pStartFrame = pStartFrame->GetFollow();
+ pEndFrame = pStartFrame;
+ while( pEndFrame->HasFollow() &&
+ nChgEnd >= pEndFrame->GetFollow()->GetOfst() )
+ pEndFrame = pEndFrame->GetFollow();
// information about start of repaint area
Sw2LinesPos* pSt2Pos = aTmpState.m_p2Lines;
if ( pSt2Pos )
{
// we are inside a special portion, take right border
- SWRECTFN( pStartFrm )
+ SWRECTFN( pStartFrame )
(aTmp.*fnRect->fnSetTop)( (pSt2Pos->aLine.*fnRect->fnGetTop)() );
- if ( pStartFrm->IsRightToLeft() )
+ if ( pStartFrame->IsRightToLeft() )
(aTmp.*fnRect->fnSetLeft)( (pSt2Pos->aPortion.*fnRect->fnGetRight)() );
else
(aTmp.*fnRect->fnSetLeft)( (pSt2Pos->aPortion.*fnRect->fnGetLeft)() );
@@ -246,45 +246,45 @@ static SwRect lcl_CalculateRepaintRect( SwTextFrm& rTextFrm, sal_Int32 nChgStart
bool bSameFrame = true;
- if( rTextFrm.HasFollow() )
+ if( rTextFrame.HasFollow() )
{
- if( pEndFrm != pStartFrm )
+ if( pEndFrame != pStartFrame )
{
bSameFrame = false;
- SwRect aStFrm( pStartFrm->PaintArea() );
+ SwRect aStFrame( pStartFrame->PaintArea() );
{
- SWRECTFN( pStartFrm )
- (aTmp.*fnRect->fnSetLeft)( (aStFrm.*fnRect->fnGetLeft)() );
- (aTmp.*fnRect->fnSetRight)( (aStFrm.*fnRect->fnGetRight)() );
- (aTmp.*fnRect->fnSetBottom)( (aStFrm.*fnRect->fnGetBottom)() );
+ SWRECTFN( pStartFrame )
+ (aTmp.*fnRect->fnSetLeft)( (aStFrame.*fnRect->fnGetLeft)() );
+ (aTmp.*fnRect->fnSetRight)( (aStFrame.*fnRect->fnGetRight)() );
+ (aTmp.*fnRect->fnSetBottom)( (aStFrame.*fnRect->fnGetBottom)() );
}
- aStFrm = pEndFrm->PaintArea();
+ aStFrame = pEndFrame->PaintArea();
{
- SWRECTFN( pEndFrm )
- (aRect.*fnRect->fnSetTop)( (aStFrm.*fnRect->fnGetTop)() );
- (aRect.*fnRect->fnSetLeft)( (aStFrm.*fnRect->fnGetLeft)() );
- (aRect.*fnRect->fnSetRight)( (aStFrm.*fnRect->fnGetRight)() );
+ SWRECTFN( pEndFrame )
+ (aRect.*fnRect->fnSetTop)( (aStFrame.*fnRect->fnGetTop)() );
+ (aRect.*fnRect->fnSetLeft)( (aStFrame.*fnRect->fnGetLeft)() );
+ (aRect.*fnRect->fnSetRight)( (aStFrame.*fnRect->fnGetRight)() );
}
aRect.Union( aTmp );
while( true )
{
- pStartFrm = pStartFrm->GetFollow();
- if( pStartFrm == pEndFrm )
+ pStartFrame = pStartFrame->GetFollow();
+ if( pStartFrame == pEndFrame )
break;
- aRect.Union( pStartFrm->PaintArea() );
+ aRect.Union( pStartFrame->PaintArea() );
}
}
}
if( bSameFrame )
{
- SWRECTFN( pStartFrm )
+ SWRECTFN( pStartFrame )
if( (aTmp.*fnRect->fnGetTop)() == (aRect.*fnRect->fnGetTop)() )
(aRect.*fnRect->fnSetLeft)( (aTmp.*fnRect->fnGetLeft)() );
else
{
- SwRect aStFrm( pStartFrm->PaintArea() );
- (aRect.*fnRect->fnSetLeft)( (aStFrm.*fnRect->fnGetLeft)() );
- (aRect.*fnRect->fnSetRight)( (aStFrm.*fnRect->fnGetRight)() );
+ SwRect aStFrame( pStartFrame->PaintArea() );
+ (aRect.*fnRect->fnSetLeft)( (aStFrame.*fnRect->fnGetLeft)() );
+ (aRect.*fnRect->fnSetRight)( (aStFrame.*fnRect->fnGetRight)() );
(aRect.*fnRect->fnSetTop)( (aTmp.*fnRect->fnGetTop)() );
}
@@ -644,7 +644,7 @@ void SwTextNode::RstTextAttr(
m_pSwpHints->MergePortions(*this);
}
- // TextFrm's respond to aHint, others to aNew
+ // TextFrame's respond to aHint, others to aNew
SwUpdateAttr aHint(
nMin,
nMax,
@@ -941,7 +941,7 @@ bool SwScanner::NextWord()
bool SwTextNode::Spell(SwSpellArgs* pArgs)
{
// Die Aehnlichkeiten zu SwTextFrm::_AutoSpell sind beabsichtigt ...
// ACHTUNG: Ev. Bugs in beiden Routinen fixen!
// modify string according to redline information and hidden text
@@ -1238,7 +1238,7 @@ bool SwTextNode::Convert( SwConversionArgs &rArgs )
// Die Aehnlichkeiten zu SwTextNode::Spell sind beabsichtigt ...
// ACHTUNG: Ev. Bugs in beiden Routinen fixen!
-SwRect SwTextFrm::_AutoSpell( const SwContentNode* pActNode, sal_Int32 nActPos )
+SwRect SwTextFrame::_AutoSpell( const SwContentNode* pActNode, sal_Int32 nActPos )
{
SwRect aRect;
#if OSL_DEBUG_LEVEL > 1
@@ -1403,7 +1403,7 @@ SwRect SwTextFrm::_AutoSpell( const SwContentNode* pActNode, sal_Int32 nActPos )
aRect = lcl_CalculateRepaintRect( *this, nChgStart, nChgEnd );
// fdo#71558 notify misspelled word to accessibility
- SwViewShell* pViewSh = getRootFrm() ? getRootFrm()->GetCurrShell() : nullptr;
+ SwViewShell* pViewSh = getRootFrame() ? getRootFrame()->GetCurrShell() : nullptr;
if( pViewSh )
pViewSh->InvalidateAccessibleParaAttrs( *this );
}
@@ -1438,7 +1438,7 @@ SwRect SwTextFrm::_AutoSpell( const SwContentNode* pActNode, sal_Int32 nActPos )
@param nActPos ???
@return SwRect Repaint area
*/
-SwRect SwTextFrm::SmartTagScan( SwContentNode* /*pActNode*/, sal_Int32 /*nActPos*/ )
+SwRect SwTextFrame::SmartTagScan( SwContentNode* /*pActNode*/, sal_Int32 /*nActPos*/ )
{
SwRect aRet;
SwTextNode *pNode = GetTextNode();
@@ -1557,7 +1557,7 @@ SwRect SwTextFrm::SmartTagScan( SwContentNode* /*pActNode*/, sal_Int32 /*nActPos
}
// Wird vom CollectAutoCmplWords gerufen
-void SwTextFrm::CollectAutoCmplWrds( SwContentNode* pActNode, sal_Int32 nActPos )
+void SwTextFrame::CollectAutoCmplWrds( SwContentNode* pActNode, sal_Int32 nActPos )
{
SwTextNode *pNode = GetTextNode();
if( pNode != pActNode || !nActPos )
@@ -1606,7 +1606,7 @@ void SwTextFrm::CollectAutoCmplWrds( SwContentNode* pActNode, sal_Int32 nActPos
pNode->SetAutoCompleteWordDirty( false );
}
-/** Findet den TextFrm und sucht dessen CalcHyph */
+/** Findet den TextFrame und sucht dessen CalcHyph */
bool SwTextNode::Hyphenate( SwInterHyphInfo &rHyphInf )
{
// Abkuerzung: am Absatz ist keine Sprache eingestellt:
@@ -1618,38 +1618,38 @@ bool SwTextNode::Hyphenate( SwInterHyphInfo &rHyphInf )
return false;
}
- SwTextFrm *pFrm = ::sw::SwHyphIterCacheLastTxtFrm(this,
+ SwTextFrame *pFrame = ::sw::SwHyphIterCacheLastTextFrame(this,
[&rHyphInf, this]() {
- return static_cast<SwTextFrm*>(this->getLayoutFrm(
+ return static_cast<SwTextFrame*>(this->getLayoutFrame(
this->GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout(),
- rHyphInf.GetCrsrPos()));
+ rHyphInf.GetCursorPos()));
});
- if( pFrm )
- pFrm = &(pFrm->GetFrmAtOfst( rHyphInf.nStart ));
+ if( pFrame )
+ pFrame = &(pFrame->GetFrameAtOfst( rHyphInf.nStart ));
else
{
// 4935: Seit der Trennung ueber Sonderbereiche sind Faelle
// moeglich, in denen kein Frame zum Node vorliegt.
// Also keinOSL_ENSURE
- OSL_ENSURE( pFrm, "!SwTextNode::Hyphenate: can't find any frame" );
+ OSL_ENSURE( pFrame, "!SwTextNode::Hyphenate: can't find any frame" );
return false;
}
- while( pFrm )
+ while( pFrame )
{
- if( pFrm->Hyphenate( rHyphInf ) )
+ if( pFrame->Hyphenate( rHyphInf ) )
{
// Das Layout ist nicht robust gegen "Direktformatierung"
// (7821, 7662, 7408); vgl. layact.cxx,
// SwLayAction::_TurboAction(), if( !pCnt->IsValid() ...
- pFrm->SetCompletePaint();
+ pFrame->SetCompletePaint();
return true;
}
- pFrm = pFrm->GetFollow();
- if( pFrm )
+ pFrame = pFrame->GetFollow();
+ if( pFrame )
{
- rHyphInf.nEnd = rHyphInf.nEnd - (pFrm->GetOfst() - rHyphInf.nStart);
- rHyphInf.nStart = pFrm->GetOfst();
+ rHyphInf.nEnd = rHyphInf.nEnd - (pFrame->GetOfst() - rHyphInf.nStart);
+ rHyphInf.nStart = pFrame->GetOfst();
}
}
return false;
@@ -941,7 +941,7 @@ bool SwScanner::NextWord()
bool SwTextNode::Spell(SwSpellArgs* pArgs)
{
- // Die Aehnlichkeiten zu SwTextFrm::_AutoSpell sind beabsichtigt ...
+ // Die Aehnlichkeiten zu SwTextFrame::_AutoSpell sind beabsichtigt ...
// ACHTUNG: Ev. Bugs in beiden Routinen fixen!
// modify string according to redline information and hidden text